summaryrefslogtreecommitdiffstats
path: root/kpilot
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit9abdf0551e3660f55791ce3720d5f7035c06aa19 (patch)
tree30466a53042f3fd9ff5d3e4db0dc1120d0d8648b /kpilot
parent539a35866f0bac8f00e493654d4a8ec6863726e2 (diff)
downloadkpilot-9abdf0551e3660f55791ce3720d5f7035c06aa19.tar.gz
kpilot-9abdf0551e3660f55791ce3720d5f7035c06aa19.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kpilot@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpilot')
-rw-r--r--kpilot/addressEditor.cc6
-rw-r--r--kpilot/addressEditor.h2
-rw-r--r--kpilot/addressWidget.cc4
-rw-r--r--kpilot/addressWidget.h2
-rw-r--r--kpilot/conduitConfigDialog.cc30
-rw-r--r--kpilot/datebookWidget.cc4
-rw-r--r--kpilot/datebookWidget.h2
-rw-r--r--kpilot/dbAppInfoEditor.cc4
-rw-r--r--kpilot/dbAppInfoEditor.h2
-rw-r--r--kpilot/dbFlagsEditor.cc4
-rw-r--r--kpilot/dbFlagsEditor.h2
-rw-r--r--kpilot/dbRecordEditor.cc4
-rw-r--r--kpilot/dbRecordEditor.h2
-rw-r--r--kpilot/dbviewerWidget.cc4
-rw-r--r--kpilot/dbviewerWidget.h2
-rw-r--r--kpilot/fileInstallWidget.cc4
-rw-r--r--kpilot/fileInstallWidget.h2
-rw-r--r--kpilot/hotSync.cc6
-rw-r--r--kpilot/kpilot.cc22
-rw-r--r--kpilot/kpilotConfigWizard.cc4
-rw-r--r--kpilot/kpilotProbeDialog.cc4
-rw-r--r--kpilot/listCat.cc12
-rw-r--r--kpilot/listCat.h8
-rw-r--r--kpilot/listItems.cc8
-rw-r--r--kpilot/listItems.h4
-rw-r--r--kpilot/logWidget.cc4
-rw-r--r--kpilot/memoWidget.cc6
-rw-r--r--kpilot/memoWidget.h2
-rw-r--r--kpilot/pilotComponent.cc10
-rw-r--r--kpilot/pilotComponent.h2
-rw-r--r--kpilot/todoEditor.cc6
-rw-r--r--kpilot/todoEditor.h2
-rw-r--r--kpilot/todoWidget.cc8
-rw-r--r--kpilot/todoWidget.h6
34 files changed, 97 insertions, 97 deletions
diff --git a/kpilot/addressEditor.cc b/kpilot/addressEditor.cc
index dc3bd25..47f9a3a 100644
--- a/kpilot/addressEditor.cc
+++ b/kpilot/addressEditor.cc
@@ -54,12 +54,12 @@
AddressEditor::AddressEditor(PilotAddress * p,
PilotAddressInfo *appInfo,
- TQWidget * tqparent,
+ TQWidget * parent,
const char *name) :
KDialogBase(KDialogBase::Plain,
i18n("Address Editor"),
Ok | Cancel, Cancel,
- tqparent, name, false /* non-modal */ ),
+ parent, name, false /* non-modal */ ),
fDeleteOnCancel(p == 0L),
fAddress(p),
fAppInfo(appInfo)
@@ -69,7 +69,7 @@ AddressEditor::AddressEditor(PilotAddress * p,
initLayout();
fillFields();
- connect(tqparent, TQT_SIGNAL(recordChanged(PilotAddress *)),
+ connect(parent, TQT_SIGNAL(recordChanged(PilotAddress *)),
this, TQT_SLOT(updateRecord(PilotAddress *)));
}
diff --git a/kpilot/addressEditor.h b/kpilot/addressEditor.h
index 07b6f10..4561da1 100644
--- a/kpilot/addressEditor.h
+++ b/kpilot/addressEditor.h
@@ -45,7 +45,7 @@ class AddressEditor : public KDialogBase
public:
AddressEditor(PilotAddress *address,
PilotAddressInfo *appInfo,
- TQWidget *tqparent, const char *name=0L);
+ TQWidget *parent, const char *name=0L);
~AddressEditor();
diff --git a/kpilot/addressWidget.cc b/kpilot/addressWidget.cc
index 056b387..676e66d 100644
--- a/kpilot/addressWidget.cc
+++ b/kpilot/addressWidget.cc
@@ -65,9 +65,9 @@
#include "addressWidget.moc"
-AddressWidget::AddressWidget(TQWidget * tqparent,
+AddressWidget::AddressWidget(TQWidget * parent,
const TQString & path) :
- PilotComponent(tqparent, "component_address", path),
+ PilotComponent(parent, "component_address", path),
fAddrInfo(0L),
fAddressAppInfo(0L),
fPendingAddresses(0)
diff --git a/kpilot/addressWidget.h b/kpilot/addressWidget.h
index 7248922..3109f8f 100644
--- a/kpilot/addressWidget.h
+++ b/kpilot/addressWidget.h
@@ -47,7 +47,7 @@ Q_OBJECT
TQ_OBJECT
public:
- AddressWidget(TQWidget* tqparent,const TQString& dbpath);
+ AddressWidget(TQWidget* parent,const TQString& dbpath);
~AddressWidget();
// Pilot Component Methods:
diff --git a/kpilot/conduitConfigDialog.cc b/kpilot/conduitConfigDialog.cc
index f2a3d54..8f47a8a 100644
--- a/kpilot/conduitConfigDialog.cc
+++ b/kpilot/conduitConfigDialog.cc
@@ -72,16 +72,16 @@
extern "C"
{
- KDE_EXPORT KCModule *create_kpilotconfig( TQWidget *tqparent, const char * )
+ KDE_EXPORT KCModule *create_kpilotconfig( TQWidget *parent, const char * )
{
FUNCTIONSETUP;
- return new ConduitConfigWidget( tqparent, "kcmkpilotconfig" );
+ return new ConduitConfigWidget( parent, "kcmkpilotconfig" );
}
- KDE_EXPORT ConfigWizard *create_wizard(TQWidget *tqparent, int m)
+ KDE_EXPORT ConfigWizard *create_wizard(TQWidget *parent, int m)
{
FUNCTIONSETUP;
- return new ConfigWizard(tqparent,"Wizard", m);
+ return new ConfigWizard(parent,"Wizard", m);
}
}
@@ -89,7 +89,7 @@ extern "C"
class ConduitTip : public TQToolTip
{
public:
- ConduitTip(TQListView *tqparent);
+ ConduitTip(TQListView *parent);
virtual ~ConduitTip();
protected:
@@ -148,7 +148,7 @@ ConduitTip::~ConduitTip()
class KPilotCheckListItem : public TQCheckListItem
{
public:
- KPilotCheckListItem ( TQListViewItem * tqparent, const TQString & text, Type tt = RadioButtonController ) : TQCheckListItem(tqparent, text, tt),mOriginalState(false) {}
+ KPilotCheckListItem ( TQListViewItem * parent, const TQString & text, Type tt = RadioButtonController ) : TQCheckListItem(parent, text, tt),mOriginalState(false) {}
~KPilotCheckListItem() {}
void setOriginalState(bool state) { mOriginalState=state; setOn(state);}
@@ -171,20 +171,20 @@ protected:
/*
-** Create a page in the widget stack @p tqparent on page @p pageno,
+** Create a page in the widget stack @p parent on page @p pageno,
** bearing the given @p text. The remainder of the parameters are
** for esoteric things like:
** @p buttons set to non-null to include (and return) a TQHBox suitable
** for displaying a row of buttons in on the page.
** @p label set to non-null to return the TQLabel used to display @p text.
*/
-static void addDescriptionPage(TQWidgetStack *tqparent,
+static void addDescriptionPage(TQWidgetStack *parent,
int pageno,
const TQString &text,
TQHBox **buttons = 0L,
TQLabel **label = 0L)
{
- TQVBox *v = new TQVBox(tqparent);
+ TQVBox *v = new TQVBox(parent);
TQLabel *l = 0L;
v->setFrameShape(TQLabel::NoFrame);
@@ -202,12 +202,12 @@ static void addDescriptionPage(TQWidgetStack *tqparent,
l = new TQLabel(v);
}
- tqparent->addWidget(v,pageno);
+ parent->addWidget(v,pageno);
}
-ConduitConfigWidgetBase::ConduitConfigWidgetBase(TQWidget *tqparent, const char *n) :
- KCModule(tqparent, n),
+ConduitConfigWidgetBase::ConduitConfigWidgetBase(TQWidget *parent, const char *n) :
+ KCModule(parent, n),
fConduitList(0L),
fStack(0L),
fConfigureButton(0L),
@@ -300,9 +300,9 @@ ConduitConfigWidgetBase::ConduitConfigWidgetBase(TQWidget *tqparent, const char
fStack->addWidget(ConduitConfigBase::aboutPage(fStack,0L),GENERAL_ABOUT);
}
-ConduitConfigWidget::ConduitConfigWidget(TQWidget *tqparent, const char *n,
+ConduitConfigWidget::ConduitConfigWidget(TQWidget *parent, const char *n,
bool) :
- ConduitConfigWidgetBase(tqparent,n),
+ ConduitConfigWidgetBase(parent,n),
fConfigure(0L),
fCurrentConduit(0L),
fGeneralPage(0L),
@@ -716,7 +716,7 @@ void ConduitConfigWidget::selected(TQListViewItem *p)
#endif
// set the dialog title to the selected item
- TQListViewItem *pParent = p->tqparent();
+ TQListViewItem *pParent = p->parent();
TQString title;
title = pParent ? pParent->text(CONDUIT_NAME) + CSL1(" - ") : TQString() ;
title += p ? p->text(CONDUIT_NAME) : i18n("KPilot Setup");
diff --git a/kpilot/datebookWidget.cc b/kpilot/datebookWidget.cc
index 7d8c851..8b76942 100644
--- a/kpilot/datebookWidget.cc
+++ b/kpilot/datebookWidget.cc
@@ -41,8 +41,8 @@
#include "datebookWidget.moc"
-DatebookWidget::DatebookWidget(TQWidget *tqparent, const TQString &dbpath) :
- PilotComponent(tqparent,"component_generic",dbpath)
+DatebookWidget::DatebookWidget(TQWidget *parent, const TQString &dbpath) :
+ PilotComponent(parent,"component_generic",dbpath)
{
FUNCTIONSETUP;
diff --git a/kpilot/datebookWidget.h b/kpilot/datebookWidget.h
index 4acfbb3..5933c7c 100644
--- a/kpilot/datebookWidget.h
+++ b/kpilot/datebookWidget.h
@@ -42,7 +42,7 @@ Q_OBJECT
TQ_OBJECT
public:
- DatebookWidget(TQWidget* tqparent, const TQString& dbpath);
+ DatebookWidget(TQWidget* parent, const TQString& dbpath);
virtual ~DatebookWidget();
// Pilot component methods
diff --git a/kpilot/dbAppInfoEditor.cc b/kpilot/dbAppInfoEditor.cc
index f0ddb1e..0011ff1 100644
--- a/kpilot/dbAppInfoEditor.cc
+++ b/kpilot/dbAppInfoEditor.cc
@@ -41,8 +41,8 @@ using namespace KHE;
/*************************************************
**************************************************/
-DBAppInfoEditor::DBAppInfoEditor(char*appInfoData, int l, TQWidget *tqparent) :
- KDialogBase(tqparent, "AppBlock Editor",false,
+DBAppInfoEditor::DBAppInfoEditor(char*appInfoData, int l, TQWidget *parent) :
+ KDialogBase(parent, "AppBlock Editor",false,
i18n("Edit AppInfo Block"),
Ok|Cancel),
appInfo(appInfoData),
diff --git a/kpilot/dbAppInfoEditor.h b/kpilot/dbAppInfoEditor.h
index 8ac9cf3..bb1111c 100644
--- a/kpilot/dbAppInfoEditor.h
+++ b/kpilot/dbAppInfoEditor.h
@@ -37,7 +37,7 @@ class DBAppInfoEditor : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- DBAppInfoEditor(char*appInfoData, int l, TQWidget *tqparent = 0);
+ DBAppInfoEditor(char*appInfoData, int l, TQWidget *parent = 0);
~DBAppInfoEditor();
char*appInfo;
int len;
diff --git a/kpilot/dbFlagsEditor.cc b/kpilot/dbFlagsEditor.cc
index 7b366f9..eafbe58 100644
--- a/kpilot/dbFlagsEditor.cc
+++ b/kpilot/dbFlagsEditor.cc
@@ -40,8 +40,8 @@
#include "dbFlagsEditor_base.h"
-DBFlagsEditor::DBFlagsEditor(DBInfo*dbinfo, TQWidget *tqparent) :
- KDialogBase(tqparent, "FlagsEditor",false,
+DBFlagsEditor::DBFlagsEditor(DBInfo*dbinfo, TQWidget *parent) :
+ KDialogBase(parent, "FlagsEditor",false,
i18n("Edit Database Flags"), Ok|Cancel),
dbi(dbinfo)
{
diff --git a/kpilot/dbFlagsEditor.h b/kpilot/dbFlagsEditor.h
index c88daf0..be58d5c 100644
--- a/kpilot/dbFlagsEditor.h
+++ b/kpilot/dbFlagsEditor.h
@@ -40,7 +40,7 @@ class DBFlagsEditor : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- DBFlagsEditor(DBInfo*dbinfo=0L, TQWidget *tqparent = 0);
+ DBFlagsEditor(DBInfo*dbinfo=0L, TQWidget *parent = 0);
~DBFlagsEditor();
protected:
diff --git a/kpilot/dbRecordEditor.cc b/kpilot/dbRecordEditor.cc
index 447d3df..ec31e26 100644
--- a/kpilot/dbRecordEditor.cc
+++ b/kpilot/dbRecordEditor.cc
@@ -49,8 +49,8 @@ using namespace KHE;
-DBRecordEditor::DBRecordEditor(PilotRecord*r, int n, TQWidget *tqparent)
- : KDialogBase(tqparent, "RecordEditor",false,i18n("Edit Record"),
+DBRecordEditor::DBRecordEditor(PilotRecord*r, int n, TQWidget *parent)
+ : KDialogBase(parent, "RecordEditor",false,i18n("Edit Record"),
Ok|Cancel), rec(r), nr(n)
{
// fWidget=new DBRecordEditorBase(this);
diff --git a/kpilot/dbRecordEditor.h b/kpilot/dbRecordEditor.h
index 338113c..aa61a92 100644
--- a/kpilot/dbRecordEditor.h
+++ b/kpilot/dbRecordEditor.h
@@ -56,7 +56,7 @@ class DBRecordEditor : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- DBRecordEditor(PilotRecord*r=0L, int n=-1, TQWidget *tqparent = 0);
+ DBRecordEditor(PilotRecord*r=0L, int n=-1, TQWidget *parent = 0);
~DBRecordEditor();
protected:
diff --git a/kpilot/dbviewerWidget.cc b/kpilot/dbviewerWidget.cc
index ff7fad1..6332760 100644
--- a/kpilot/dbviewerWidget.cc
+++ b/kpilot/dbviewerWidget.cc
@@ -64,8 +64,8 @@
#include "dbviewerWidget.moc"
-GenericDBWidget::GenericDBWidget(TQWidget *tqparent, const TQString &dbpath) :
- PilotComponent(tqparent,"component_generic",dbpath), fDB(0L)
+GenericDBWidget::GenericDBWidget(TQWidget *parent, const TQString &dbpath) :
+ PilotComponent(parent,"component_generic",dbpath), fDB(0L)
{
FUNCTIONSETUP;
setupWidget();
diff --git a/kpilot/dbviewerWidget.h b/kpilot/dbviewerWidget.h
index 0a5f2d1..760ac45 100644
--- a/kpilot/dbviewerWidget.h
+++ b/kpilot/dbviewerWidget.h
@@ -46,7 +46,7 @@ Q_OBJECT
TQ_OBJECT
public:
- GenericDBWidget(TQWidget* tqparent, const TQString& dbpath);
+ GenericDBWidget(TQWidget* parent, const TQString& dbpath);
virtual ~GenericDBWidget();
// Pilot component methods
diff --git a/kpilot/fileInstallWidget.cc b/kpilot/fileInstallWidget.cc
index c9ce561..5e11c46 100644
--- a/kpilot/fileInstallWidget.cc
+++ b/kpilot/fileInstallWidget.cc
@@ -58,9 +58,9 @@
#include "fileInstallWidget.moc"
-FileInstallWidget::FileInstallWidget(TQWidget * tqparent,
+FileInstallWidget::FileInstallWidget(TQWidget * parent,
const TQString & path) :
- PilotComponent(tqparent, "component_files", path),
+ PilotComponent(parent, "component_files", path),
fSaveFileList(false),
fInstaller(0L)
{
diff --git a/kpilot/fileInstallWidget.h b/kpilot/fileInstallWidget.h
index b12fd00..29e3daa 100644
--- a/kpilot/fileInstallWidget.h
+++ b/kpilot/fileInstallWidget.h
@@ -48,7 +48,7 @@ Q_OBJECT
TQ_OBJECT
public:
- FileInstallWidget(TQWidget* tqparent, const TQString& dbPath);
+ FileInstallWidget(TQWidget* parent, const TQString& dbPath);
virtual ~FileInstallWidget();
// Pilot Component Methods:
diff --git a/kpilot/hotSync.cc b/kpilot/hotSync.cc
index 96e006c..7689f32 100644
--- a/kpilot/hotSync.cc
+++ b/kpilot/hotSync.cc
@@ -68,7 +68,7 @@
class BackupAction::Thread : public TQThread
{
public:
- Thread( BackupAction *tqparent,
+ Thread( BackupAction *parent,
KPilotLink *link,
const TQString &filename,
const DBInfo *info );
@@ -1128,12 +1128,12 @@ void RestoreAction::setDirectory( const TQString &path )
-BackupAction::Thread::Thread( BackupAction *tqparent,
+BackupAction::Thread::Thread( BackupAction *parent,
KPilotLink *link,
const TQString &filename,
const DBInfo *info )
{
- fParent = tqparent;
+ fParent = parent;
fLink = link;
fFilename = filename;
memcpy(&fDBInfo,info,sizeof(DBInfo));
diff --git a/kpilot/kpilot.cc b/kpilot/kpilot.cc
index 328029f..246fd9a 100644
--- a/kpilot/kpilot.cc
+++ b/kpilot/kpilot.cc
@@ -320,21 +320,21 @@ void KPilotInstaller::slotSelectComponent(PilotComponent *c)
return;
}
- TQObject *o = c->tqparent();
+ TQObject *o = c->parent();
if (!o)
{
- WARNINGKPILOT << "Widget has no tqparent." << endl;
+ WARNINGKPILOT << "Widget has no parent." << endl;
return;
}
- TQWidget *tqparent = dynamic_cast<TQWidget *>(o);
- if (!tqparent)
+ TQWidget *parent = dynamic_cast<TQWidget *>(o);
+ if (!parent)
{
- WARNINGKPILOT << "Widget's tqparent is not a widget." << endl;
+ WARNINGKPILOT << "Widget's parent is not a widget." << endl;
return;
}
- int index = fManagingWidget->pageIndex(tqparent);
+ int index = fManagingWidget->pageIndex(parent);
if (index < 0)
{
@@ -741,7 +741,7 @@ void KPilotInstaller::slotResetLink()
/*
** Can't be a member function because it needs to be called even with no KPilotInstaller.
*/
-static bool runConfigure(PilotDaemonDCOP_stub &daemon,TQWidget *tqparent)
+static bool runConfigure(PilotDaemonDCOP_stub &daemon,TQWidget *parent)
{
FUNCTIONSETUP;
bool ret = false;
@@ -754,7 +754,7 @@ static bool runConfigure(PilotDaemonDCOP_stub &daemon,TQWidget *tqparent)
KPilotSettings::self()->readConfig();
- KCMultiDialog *options = new KCMultiDialog( KDialogBase::Plain, i18n("Configuration"), tqparent, "KPilotPreferences", true );
+ KCMultiDialog *options = new KCMultiDialog( KDialogBase::Plain, i18n("Configuration"), parent, "KPilotPreferences", true );
options->addModule( CSL1("kpilot_config.desktop") );
if (!options)
@@ -796,7 +796,7 @@ static bool runConfigure(PilotDaemonDCOP_stub &daemon,TQWidget *tqparent)
* canceled, though).
*/
typedef enum { Failed, OK, Cancel } WizardResult;
-static WizardResult runWizard(PilotDaemonDCOP_stub &daemon,TQWidget *tqparent)
+static WizardResult runWizard(PilotDaemonDCOP_stub &daemon,TQWidget *parent)
{
FUNCTIONSETUP;
WizardResult ret = Failed ;
@@ -826,7 +826,7 @@ static WizardResult runWizard(PilotDaemonDCOP_stub &daemon,TQWidget *tqparent)
goto sorry;
}
- w = f(tqparent,ConfigWizard::Standalone);
+ w = f(parent,ConfigWizard::Standalone);
if (!w)
{
WARNINGKPILOT << "Can't create wizard." << endl;
@@ -847,7 +847,7 @@ static WizardResult runWizard(PilotDaemonDCOP_stub &daemon,TQWidget *tqparent)
sorry:
if (Failed == ret)
{
- KMessageBox::sorry(tqparent,
+ KMessageBox::sorry(parent,
i18n("The library containing the configuration wizard for KPilot "
"could not be loaded, and the wizard is not available. "
"Please try to use the regular configuration dialog."),
diff --git a/kpilot/kpilotConfigWizard.cc b/kpilot/kpilotConfigWizard.cc
index fd6036d..0b5b881 100644
--- a/kpilot/kpilotConfigWizard.cc
+++ b/kpilot/kpilotConfigWizard.cc
@@ -52,8 +52,8 @@
#include "kpilotProbeDialog.h"
-ConfigWizard::ConfigWizard(TQWidget *tqparent, const char *n, int m) :
- KWizard(tqparent, n),
+ConfigWizard::ConfigWizard(TQWidget *parent, const char *n, int m) :
+ KWizard(parent, n),
fMode((Mode)m)
{
// page1=new ConfigWizard_base1(this);
diff --git a/kpilot/kpilotProbeDialog.cc b/kpilot/kpilotProbeDialog.cc
index db62f9d..67da0e6 100644
--- a/kpilot/kpilotProbeDialog.cc
+++ b/kpilot/kpilotProbeDialog.cc
@@ -86,8 +86,8 @@ and the module can't be unloaded.
*/
-ProbeDialog::ProbeDialog(TQWidget *tqparent, const char *n) :
- KDialogBase(tqparent, n, true, i18n("Autodetecting Your Handheld"), KDialogBase::Ok|KDialogBase::Cancel|KDialogBase::User1, KDialogBase::Cancel, true, i18n("Restart Detection")),
+ProbeDialog::ProbeDialog(TQWidget *parent, const char *n) :
+ KDialogBase(parent, n, true, i18n("Autodetecting Your Handheld"), KDialogBase::Ok|KDialogBase::Cancel|KDialogBase::User1, KDialogBase::Cancel, true, i18n("Restart Detection")),
mDetected(false), mUserName(), mDevice()
{
FUNCTIONSETUP;
diff --git a/kpilot/listCat.cc b/kpilot/listCat.cc
index a5b2966..a5bf4f2 100644
--- a/kpilot/listCat.cc
+++ b/kpilot/listCat.cc
@@ -36,9 +36,9 @@
#include "listCat.moc"
-ListCategorizer::ListCategorizer(TQWidget * tqparent,
+ListCategorizer::ListCategorizer(TQWidget * parent,
const char *name) :
- KListView(tqparent, name),
+ KListView(parent, name),
fStartOpen(false)
{
FUNCTIONSETUP;
@@ -47,9 +47,9 @@ ListCategorizer::ListCategorizer(TQWidget * tqparent,
ListCategorizer::ListCategorizer(const TQStringList & i,
bool startOpen,
- TQWidget * tqparent,
+ TQWidget * parent,
const char *name) :
- KListView(tqparent, name),
+ KListView(parent, name),
fStartOpen(startOpen)
{
FUNCTIONSETUP;
@@ -121,7 +121,7 @@ void ListCategorizer::setupWidget()
return;
}
- TQListViewItem *category = p->tqparent();
+ TQListViewItem *category = p->parent();
if (!category)
{
@@ -136,7 +136,7 @@ void ListCategorizer::setupWidget()
FUNCTIONSETUP;
TQListViewItem *p = currentItem();
- if (!p || !p->tqparent())
+ if (!p || !p->parent())
return;
KListView::startDrag();
diff --git a/kpilot/listItems.cc b/kpilot/listItems.cc
index 2b5b98e..7db37cc 100644
--- a/kpilot/listItems.cc
+++ b/kpilot/listItems.cc
@@ -94,8 +94,8 @@ PilotListItem::~PilotListItem()
}
#endif
-PilotCheckListItem::PilotCheckListItem(TQListView * tqparent, const TQString & text, recordid_t pilotid, void *r) :
- TQCheckListItem(tqparent, text, TQCheckListItem::CheckBox),
+PilotCheckListItem::PilotCheckListItem(TQListView * parent, const TQString & text, recordid_t pilotid, void *r) :
+ TQCheckListItem(parent, text, TQCheckListItem::CheckBox),
fid(pilotid),
fr(r)
{
@@ -142,10 +142,10 @@ void PilotCheckListItem::stateChange ( bool on)
}
#endif
-PilotListViewItem::PilotListViewItem( TQListView * tqparent,
+PilotListViewItem::PilotListViewItem( TQListView * parent,
TQString label1, TQString label2, TQString label3, TQString label4,
recordid_t pilotid, void *r):
- TQListViewItem(tqparent, label1, label2, label3, label4,
+ TQListViewItem(parent, label1, label2, label3, label4,
TQString(), TQString(), TQString(), TQString()),
fid(pilotid),
fr(r),
diff --git a/kpilot/listItems.h b/kpilot/listItems.h
index b08cade..f676b01 100644
--- a/kpilot/listItems.h
+++ b/kpilot/listItems.h
@@ -59,7 +59,7 @@ private:
class PilotCheckListItem : public TQCheckListItem
{
public:
- PilotCheckListItem( TQListView * tqparent, const TQString & text, recordid_t pilotid=0, void *r=0);
+ PilotCheckListItem( TQListView * parent, const TQString & text, recordid_t pilotid=0, void *r=0);
virtual ~PilotCheckListItem();
recordid_t id() const {return fid;};
const void *rec() const {return fr;};
@@ -85,7 +85,7 @@ struct PilotListViewItemData
class PilotListViewItem : public TQListViewItem
{
public:
- PilotListViewItem( TQListView * tqparent,
+ PilotListViewItem( TQListView * parent,
TQString label1, TQString label2 = TQString(),
TQString label3 = TQString(), TQString label4 = TQString(),
recordid_t pilotid=0, void *r=0);
diff --git a/kpilot/logWidget.cc b/kpilot/logWidget.cc
index 5d7fb2d..1ff7ae9 100644
--- a/kpilot/logWidget.cc
+++ b/kpilot/logWidget.cc
@@ -59,9 +59,9 @@
#define TE_EOL "\n"
-LogWidget::LogWidget(TQWidget * tqparent) :
+LogWidget::LogWidget(TQWidget * parent) :
DCOPObject("LogIface"),
- PilotComponent(tqparent, "component_log", TQString()),
+ PilotComponent(parent, "component_log", TQString()),
fLog(0L),
fShowTime(false),
fSplash(0L),
diff --git a/kpilot/memoWidget.cc b/kpilot/memoWidget.cc
index 6d95ec9..c471719 100644
--- a/kpilot/memoWidget.cc
+++ b/kpilot/memoWidget.cc
@@ -74,9 +74,9 @@ public:
} ;
-MemoWidget::MemoWidget(TQWidget * tqparent,
+MemoWidget::MemoWidget(TQWidget * parent,
const TQString & path) :
- PilotComponent(tqparent, "component_memo", path),
+ PilotComponent(parent, "component_memo", path),
fTextWidget(0L),
d(new Private()),
lastSelectedMemo(-1)
@@ -84,7 +84,7 @@ MemoWidget::MemoWidget(TQWidget * tqparent,
FUNCTIONSETUP;
setGeometry(0, 0,
- tqparent->tqgeometry().width(), tqparent->tqgeometry().height());
+ parent->tqgeometry().width(), parent->tqgeometry().height());
setupWidget();
d->fMemoList.setAutoDelete(true);
slotUpdateButtons();
diff --git a/kpilot/memoWidget.h b/kpilot/memoWidget.h
index a260b67..c979d5d 100644
--- a/kpilot/memoWidget.h
+++ b/kpilot/memoWidget.h
@@ -45,7 +45,7 @@ Q_OBJECT
TQ_OBJECT
public:
- MemoWidget(TQWidget* tqparent, const TQString& dbpath);
+ MemoWidget(TQWidget* parent, const TQString& dbpath);
virtual ~MemoWidget();
// Pilot Component Methods:
diff --git a/kpilot/pilotComponent.cc b/kpilot/pilotComponent.cc
index dcc8b34..5908479 100644
--- a/kpilot/pilotComponent.cc
+++ b/kpilot/pilotComponent.cc
@@ -46,19 +46,19 @@
#include "pilotComponent.moc"
-PilotComponent::PilotComponent(TQWidget * tqparent,
+PilotComponent::PilotComponent(TQWidget * parent,
const char *id,
const TQString & path) :
- TQWidget(tqparent, id),
+ TQWidget(parent, id),
fDBPath(path),
shown(false)
{
FUNCTIONSETUP;
- if (tqparent)
+ if (parent)
{
- resize(tqparent->tqgeometry().width(),
- tqparent->tqgeometry().height());
+ resize(parent->tqgeometry().width(),
+ parent->tqgeometry().height());
}
}
diff --git a/kpilot/pilotComponent.h b/kpilot/pilotComponent.h
index 30a7845..8e64792 100644
--- a/kpilot/pilotComponent.h
+++ b/kpilot/pilotComponent.h
@@ -45,7 +45,7 @@ Q_OBJECT
friend class KPilotInstaller;
public:
- PilotComponent(TQWidget* tqparent,
+ PilotComponent(TQWidget* parent,
const char *id,
const TQString& dbPath);
diff --git a/kpilot/todoEditor.cc b/kpilot/todoEditor.cc
index 9ba89f1..d7017bb 100644
--- a/kpilot/todoEditor.cc
+++ b/kpilot/todoEditor.cc
@@ -45,8 +45,8 @@
TodoEditor::TodoEditor(PilotTodoEntry * p, struct ToDoAppInfo *appInfo,
- TQWidget * tqparent, const char *name) :
- KDialogBase(tqparent, name, false, i18n("To-do Editor"), Ok|Cancel),
+ TQWidget * parent, const char *name) :
+ KDialogBase(parent, name, false, i18n("To-do Editor"), Ok|Cancel),
fDeleteOnCancel(p == 0L),
fTodo(p),
fAppInfo(appInfo)
@@ -57,7 +57,7 @@ TodoEditor::TodoEditor(PilotTodoEntry * p, struct ToDoAppInfo *appInfo,
setMainWidget(fWidget);
fillFields();
- connect(tqparent, TQT_SIGNAL(recordChanged(PilotTodoEntry *)),
+ connect(parent, TQT_SIGNAL(recordChanged(PilotTodoEntry *)),
this, TQT_SLOT(updateRecord(PilotTodoEntry *)));
}
diff --git a/kpilot/todoEditor.h b/kpilot/todoEditor.h
index 523e1bb..1a0d017 100644
--- a/kpilot/todoEditor.h
+++ b/kpilot/todoEditor.h
@@ -50,7 +50,7 @@ class TodoEditor : public KDialogBase
public:
TodoEditor(PilotTodoEntry *todo,
struct ToDoAppInfo *appInfo,
- TQWidget *tqparent, const char *name=0L);
+ TQWidget *parent, const char *name=0L);
~TodoEditor();
diff --git a/kpilot/todoWidget.cc b/kpilot/todoWidget.cc
index cb09911..a095685 100644
--- a/kpilot/todoWidget.cc
+++ b/kpilot/todoWidget.cc
@@ -49,8 +49,8 @@
-TodoCheckListItem::TodoCheckListItem(TQListView*tqparent, const TQString&text,
- recordid_t pilotid, void*r):PilotCheckListItem(tqparent, text, pilotid, r)
+TodoCheckListItem::TodoCheckListItem(TQListView*parent, const TQString&text,
+ recordid_t pilotid, void*r):PilotCheckListItem(parent, text, pilotid, r)
{
}
@@ -63,9 +63,9 @@ void TodoCheckListItem::stateChange(bool state)
-TodoWidget::TodoWidget(TQWidget * tqparent,
+TodoWidget::TodoWidget(TQWidget * parent,
const TQString & path) :
- PilotComponent(tqparent, "component_todo", path),
+ PilotComponent(parent, "component_todo", path),
fTodoInfo(0L),
fTodoAppInfo(0L),
fTodoDB(0L),
diff --git a/kpilot/todoWidget.h b/kpilot/todoWidget.h
index d4b5276..9a8259d 100644
--- a/kpilot/todoWidget.h
+++ b/kpilot/todoWidget.h
@@ -43,7 +43,7 @@ class TodoListView : public KListView
Q_OBJECT
TQ_OBJECT
public:
- TodoListView(TQWidget * tqparent = 0, const char * name = 0 ):KListView(tqparent, name){};
+ TodoListView(TQWidget * parent = 0, const char * name = 0 ):KListView(parent, name){};
~TodoListView() {};
signals:
void itemChecked(TQCheckListItem*item);
@@ -59,7 +59,7 @@ public:
class TodoCheckListItem : public PilotCheckListItem
{
public:
- TodoCheckListItem(TQListView*tqparent, const TQString&text, recordid_t pilotid, void*r);
+ TodoCheckListItem(TQListView*parent, const TQString&text, recordid_t pilotid, void*r);
~TodoCheckListItem() {};
virtual void stateChange(bool state);
};
@@ -70,7 +70,7 @@ Q_OBJECT
TQ_OBJECT
public:
- TodoWidget(TQWidget* tqparent,const TQString& dbpath);
+ TodoWidget(TQWidget* parent,const TQString& dbpath);
~TodoWidget();
// Pilot Component Methods:
diff --git a/kpilot/listCat.h b/kpilot/listCat.h
index 9f094e0..b90a5e6 100644
--- a/kpilot/listCat.h
+++ b/kpilot/listCat.h
@@ -72,9 +72,9 @@ public:
*
* This creates a new empty ListCategorizer with
* startOpen set to false. The parameters
* @p tqparent and @p name are the usual TQt ones.
*/
- ListCategorizer(TQWidget *tqparent,
+ ListCategorizer(TQWidget *parent,
const char *name = 0);
/**
* Constructor.
@@ -85,7 +85,7 @@ public:
*/
ListCategorizer(const TQStringList& categories,
bool startOpen,
- TQWidget *tqparent,
+ TQWidget *parent,
const char *name = 0);
/**
@@ -201,7 +201,7 @@ private:
class RichListViewItem : public TQListViewItem
{
public:
- RichListViewItem(TQListViewItem *tqparent,
+ RichListViewItem(TQListViewItem *parent,
TQString,
int);
virtual ~RichListViewItem();
@@ -72,9 +72,9 @@ public:
* This creates a new empty ListCategorizer with
* startOpen set to false. The parameters
- * @p tqparent and @p name are the usual TQt ones.
+ * @p parent and @p name are the usual TQt ones.
*/